# AIHub

#### 目标检测
- [YOLOv5](https://github.com/ultralytics/yolov5)
- [Mask_RCNN](https://github.com/matterport/Mask_RCNN)
- [mmdetection](https://github.com/open-mmlab/mmdetection)
- [EfficientNet](https://github.com/lukemelas/EfficientNet-PyTorch)
- [EfficientDet](https://github.com/google/automl/tree/master/efficientdet)
- [DETR](https://github.com/facebookresearch/detr)
- [CenterNet](https://github.com/xingyizhou/CenterNet)

#### 语义分割

- [U^2-Net](https://github.com/xuebinqin/U-2-Net)
- [ModNet](https://github.com/ZHKKKe/MODNet)
- [Robust Video Matting](https://peterl1n.github.io/RobustVideoMatting/#/): [CODE](https://github.com/PeterL1n/RobustVideoMatting)

#### 风格/属性迁移

- [StarGAN v2](https://github.com/clovaai/stargan-v2)
- [StyleGAN2](https://github.com/NVlabs/stylegan2-ada-pytorch)
- [StyleCLIP](https://github.com/orpatashnik/StyleCLIP)
- [ALAE](https://github.com/podgorskiy/ALAE)
- [CUT](https://github.com/taesungp/contrastive-unpaired-translation)

#### 超分辨率

- [Real-ESRGAN](https://github.com/xinntao/Real-ESRGAN)
- [DRN](https://github.com/guoyongcs/DRN)
- [GFPGAN](https://github.com/TencentARC/GFPGAN)
- [SREZ](https://github.com/david-gpu/srez)
- [SuperResolution](https://github.com/krasserm/super-resolution)
- [Image Super Resolution](https://github.com/idealo/image-super-resolution)

#### 图片拟合

- [PyMatting](https://github.com/pymatting/pymatting)
- [Deep Image Matting](https://github.com/foamliu/Deep-Image-Matting-PyTorch)
- [MGMatting](https://github.com/yucornetto/MGMatting)
- [BackgroundMattingV2](https://github.com/PeterL1n/BackgroundMattingV2)

#### 图片增强
- [DPED](https://github.com/aiff22/DPED)
- [CURL](https://github.com/sjmoran/CURL)
- [EnlightenGAN](https://github.com/VITA-Group/EnlightenGAN)

#### 图片修复

- [Bringing old photos](https://github.com/microsoft/Bringing-Old-Photos-Back-to-Life)
- [DeblurGANv2](https://github.com/VITA-Group/DeblurGANv2)

#### 图片摘要

- [Tutorial to Image Captioning](https://github.com/sgrvinod/a-PyTorch-Tutorial-to-Image-Captioning)

#### 目标跟踪

- [Yolov5_DeepSort](https://github.com/mikel-brostrom/Yolov5_DeepSort_Pytorch)

#### 视频补帧

- [RIFE](https://github.com/hzwer/arXiv2020-RIFE)

#### 向量引擎 / NN
- [Milvus](https://github.com/milvus-io/milvus)
- [Faiss](https://github.com/facebookresearch/faiss)
- [Hnswlib](https://github.com/nmslib/hnswlib)
- [PySparNN](https://github.com/facebookresearch/pysparnn)

#### 以图搜图
- [ImageDedup](https://idealo.github.io/imagededup)
